#ifndef QNETWORKACCESSMANAGER_H
#define QNETWORKACCESSMANAGER_H

#include <QObject>
#include <QStringList>

class QNetworkReply;

class QNetworkAccessManager : public QObject
{
    Q_OBJECT
public:
    QNetworkAccessManager(QObject *parent = 0); 
    QNetworkReply *get(const class QNetworkRequest&);
    static QStringList urls;

signals:
    void finished(QNetworkReply*);
};

#endif //QNETWORKACCESSMANAGER_H

